@@ -1,30 +1,18 @@
 /*
- *   Copyright (C) 2000 Matthias Elter <elter@kde.org>
- *   Copyright (C) 2001-2002 Raffaele Sandrini <sandrini@kde.org>
- *   Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *   Copyright (C) 2008 Laurent Montel <montel@kde.org>
+ *   SPDX-FileCopyrightText: 2000 Matthias Elter <elter@kde.org>
+ *   SPDX-FileCopyrightText: 2001-2002 Raffaele Sandrini <sandrini@kde.org>
+ *   SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+ *   SPDX-FileCopyrightText: 2008 Laurent Montel <montel@kde.org>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #ifndef treeview_h
 #define treeview_h
 
-#include <QTreeWidget>
 #include <QMimeData>
+#include <QTreeWidget>
 
 #include <KService>
 #include <KServiceGroup>
@@ -141,7 +129,7 @@ public:
 
     void load();
 
-    //virtual void paintCell(QPainter * p, const QColorGroup & cg, int column, int width, int align);
+    // virtual void paintCell(QPainter * p, const QColorGroup & cg, int column, int width, int align);
 
 private:
     void update();
@@ -209,7 +197,7 @@ protected:
         SortByName = 0,
         SortByDescription,
         SortAllByName,
-        SortAllByDescription
+        SortAllByDescription,
     };
 
     void contextMenuEvent(QContextMenuEvent *event) override;
